# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-09-12 18:23
from __future__ import unicode_literals

import djmongo.dataimport.models
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='DataImport',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file1', models.FileField(upload_to=djmongo.dataimport.models.update_import_filename, verbose_name=b'File to be imported')),
                ('input_format', models.CharField(choices=[(b'csv', b'Comma Seperated Value (.csv)')], default=b'csv', max_length=4)),
                ('delete_collection_before_import', models.BooleanField(default=False)),
                ('status', models.CharField(default=b'New', editable=False, max_length=10, verbose_name=b'Status')),
                ('response', models.TextField(blank=True, default=b'', max_length=2048, verbose_name=b'Response')),
                ('database_name', models.CharField(max_length=256)),
                ('collection_name', models.CharField(max_length=256)),
                ('creation_date', models.DateField(auto_now_add=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ('-creation_date',),
                'get_latest_by': 'creation_date',
            },
        ),
    ]
