# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-09-28 16:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('console', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='createhistory',
            name='history',
            field=models.BooleanField(default=False, help_text='Check this to create a historical collection.\n                    When items are updated, the old data is saved in\n                    another collection'),
        ),
    ]
