# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-10-06 14:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('search', '0003_auto_20161006_1437'),
    ]

    operations = [
        migrations.AlterField(
            model_name='httpauthreadapi',
            name='slug',
            field=models.SlugField(
                help_text=b'Give your API a unique name',
                max_length=100,
                unique=True),
        ),
        migrations.AlterField(
            model_name='publicreadapi',
            name='slug',
            field=models.SlugField(
                help_text=b'Give your API a unique name',
                max_length=100,
                unique=True),
        ),
    ]
