# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-09-28 16:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aggregations', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='aggregation',
            name='output_collection_name',
            field=models.CharField(help_text=b'The resulting collection.\n        Do not include $out in your pipeline.', max_length=256),
        ),
    ]
