# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-09-12 18:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CreateHistory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('database_name', models.CharField(max_length=100, unique=True)),
                ('collection_name', models.CharField(max_length=100, unique=True)),
                ('history', models.BooleanField(default=False, help_text=b'Check this to create a historical collection. When items are updated, the old data is saved in another collection')),
            ],
            options={
                'verbose_name_plural': 'Create Histories',
            },
        ),
        migrations.AlterUniqueTogether(
            name='createhistory',
            unique_together=set([('database_name', 'collection_name')]),
        ),
    ]
